==> jupyterlab_vim-4.0.2.tar.gz: jupyterlab_vim-4.0.2/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 4.0.2

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v4.0.1...929b801ab0e3df63d24f277630c2d3ab6d3be146))

### Enhancements made

- Clear input state if applicable before hopping out of normal mode to jupyter command mode [#82](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/82) ([@ryantam626](https://github.com/ryantam626))

### Bugs fixed

- fix: override browser shift-esc in command mode [#100](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/100) ([@ianhi](https://github.com/ianhi))
  - Additional thanks to [@petergthatsme](https://github.com/petergthatsme) [@firai](https://github.com/firai) [@lukashergt](https://github.com/lukashergt) for reporting, debugging and testing
- Fix __init__.py for wheel [#99](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/99) ([@fcollonval](https://github.com/fcollonval))

### Maintenance and upkeep improvements

- fix: dev install + lint issues [#97](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/97) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2023-08-01&to=2023-08-03&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Afcollonval+updated%3A2023-08-01..2023-08-03&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2023-08-01..2023-08-03&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2023-08-01..2023-08-03&type=Issues) | [@ryantam626](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aryantam626+updated%3A2023-08-01..2023-08-03&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 4.0.1

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v4.0.0...9aa55aad927c578d91e51f351bb5bcf987d03c46))

### Enhancements made

- build: don't require package.json for python import [#93](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/93) ([@ianhi](https://github.com/ianhi))

### Bugs fixed

- Fix for attempting to update editor when there was none [#95](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/95) ([@krassowski](https://github.com/krassowski))

### Maintenance and upkeep improvements

- style: lint [#96](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/96) ([@ianhi](https://github.com/ianhi))
- build: don't require package.json for python import [#93](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/93) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2023-07-31&to=2023-08-01&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2023-07-31..2023-08-01&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2023-07-31..2023-08-01&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Akrassowski+updated%3A2023-07-31..2023-08-01&type=Issues)

## 4.0.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/1.1.0...718d294cbbab1010ffaf35c79773e3abc5d98a6c))

### Enhancements made

- Add support for vim mode in Text Editor [#90](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/90) ([@krassowski](https://github.com/krassowski))

### Bugs fixed

- Fix undo [#92](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/92) ([@krassowski](https://github.com/krassowski))
- BUG: Arrow keys navigation causes double cell hops [#77](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/77) ([@alexveden](https://github.com/alexveden))

### Maintenance and upkeep improvements

- Remove duplicate binder-on-pr action [#91](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/91) ([@krassowski](https://github.com/krassowski))
- maintenance: Release updates [#87](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/87) ([@ianhi](https://github.com/ianhi))
- Support JupyterLab 4.0 [#85](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/85) ([@krassowski](https://github.com/krassowski))

### Other merged PRs

- Add configuration to provide custom keybindings [#74](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/74) ([@peytondmurray](https://github.com/peytondmurray))
- Add "leave-current-mode" command to move insert->normal->command. [#69](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/69) ([@asford](https://github.com/asford))
- restore correct keybinding [#64](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/64) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2022-03-12&to=2023-07-31&type=c))

[@alexveden](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aalexveden+updated%3A2022-03-12..2023-07-31&type=Issues) | [@asford](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aasford+updated%3A2022-03-12..2023-07-31&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2022-03-12..2023-07-31&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2022-03-12..2023-07-31&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Akrassowski+updated%3A2022-03-12..2023-07-31&type=Issues) | [@peytondmurray](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Apeytondmurray+updated%3A2022-03-12..2023-07-31&type=Issues)

# History

## 0.17.0 / 2023-07-30

- Support JupyterLab 4.0 (#85, thanks @krassowski)

## 0.16.0 / 2023-03-12

- Add configuration to provide custom keybindings (#74, thanks @peytondmurray)
- Add bindable command to move insert-to-normal-to-command modes (#69, thanks @asford)
- Fix bug where arrow keys navigation caused double cell hops (#77, thanks @alexveden)

## 0.15.1 / 2022-03-12

- Fixed a bug in `0.15.0` where you could no longer type `c`.

## 0.15.0 / 2022-03-11

- Homogenize the project with the jupyterlab-contrib organization (#46)
- Fix `Esc` being override by the shortcuts extensions in jupyterlab
- Restructure Project Code and make keybindings user modifiable (#58)
- Add a menu button for enable/disable (#58)

## 0.14.0 / 2021-05-04

- Add ability to enable/disable plugin in settings (#24)

## 0.13.3 / 2021-02-22

- Fix saving column position when moving by lines (#28)

## 0.13.0 / 2020-12-10

- Support JupyterLab 3+
- Set up eslint and prettier

## 0.12.4 / 2020-05-20

- Switch from travis to GitHub actions.
- Auto deployment when merging to master.
- Auto bump of versions.

## 0.12.3 / 2020-04-25

- `z c` hides selected code cell
- `z o` shows selected code cell
- `z m` hides all code cells
- `z r` shows all code cells

## 0.12.2 / 2020-03-09

- Change package.json information

## 0.12.1 / 2020-03-06

- `ctrl [` exits Vim insert mode

## 0.12.0 / 2020-03-06

- Support JupyterLab 2.0.0+

## 0.11.0 / 2019-07-13

- Support JupyterLab 1.0.0+

## 0.10.1 / 2018-11-21

- `ctrl i` enters Vim insert mode from Jupyter command mode (#71) Thanks @wmayner

## 0.10.0 / 2018-10-08

- Update for JupyterLab 0.35

## 0.9.0 / 2018-08-22

- Update for JupyterLab 0.34 (#57) Thanks @MisterVulcan

## 0.8.0 / 2018-08-01

- Update for JupyterLab 0.33 (#52) Thanks @ah-

## 0.7.0 / 2018-04-16

- Requires JupyterLab 0.32 (Beta 2)
- ctrl-g shows function signature (#36)

## 0.6.0 / 2018-03-28

- center cell command (#33)
- `-` splits cell in vim command mode (#33)
- ctrl-c copies instead of leaving insert mode if you aren't on a mac (#34)

## 0.5.0 / 2018-03-27

- add moving cell commands
- Add delete/yank/paste cell commands (#28)
- select first and last cell shortcuts (#24)
- change to focus selector to fix debug prompt select

## 0.4.1 / 2018-02-14

- Ctrl-J and Ctrl-K execute markdown when leaving the cell.

## 0.4.0 / 2018-02-13

- Added Command/Ctrl-{1,2,3} to switch cell mode to code, markdown and raw.

## 0.3.0 / 2018-02-12

- Ex commands ':q' and ':quit' leave vim mode

## 0.2.1 / 2018-01-13

- bump package requirements, revert unnecessary commands for staying in edit mode
- ":w" saves notebook

## 0.2.0 / 2018-01-12

- Update to JupyterLab 0.31 (Beta1)

## 0.1.0 / 2017-12-09

- Initial Release!
- Vim mode in notebook cells
- Copy, Cut, Paste commands
- Vim motions moving between cells
- Several commands extended to remain in Vim mode

==> jupyterlab_vim-4.1.0.tar.gz: jupyterlab_vim-4.1.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 4.1.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v4.0.3...c8cc5febb0bcc419efb0b801108b97a946a71364))

### Enhancements made

- Add settings to enable double duty `Esc` and to disable `Shift-Esc` override in Command mode [#110](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/110) ([@firai](https://github.com/firai))

### Bugs fixed

- Don't render Markdown when attempting to navigate above first cell [#119](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/119) ([@firai](https://github.com/firai))

### Maintenance and upkeep improvements

- Correct license classifier in `pyproject.toml` [#122](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/122) ([@firai](https://github.com/firai))
- Correct project name to `jupyterlab-vim` [#114](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/114) ([@krassowski](https://github.com/krassowski))

### Documentation improvements

- Delete `installing.md` and mention in README [#121](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/121) ([@firai](https://github.com/firai))
- Clarify settings location [#116](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/116) ([@joelostblom](https://github.com/joelostblom))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2023-09-06&to=2023-10-12&type=c))

[@firai](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Afirai+updated%3A2023-09-06..2023-10-12&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2023-09-06..2023-10-12&type=Issues) | [@joelostblom](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Ajoelostblom+updated%3A2023-09-06..2023-10-12&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Akrassowski+updated%3A2023-09-06..2023-10-12&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 4.0.3

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v4.0.2...75d6969623b361edb428539288e60fa4f98f20cc))

### Bugs fixed

- Fix search box `Esc` bindings [#107](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/107) ([@firai](https://github.com/firai))

* Fix `modifyCell` or `modifyEditor` not called after text editor is opened after notebook by @firai in https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/105

### Maintenance and upkeep improvements

- Update README.md for `main` branch [#108](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/108) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2023-08-03&to=2023-09-06&type=c))

[@firai](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Afirai+updated%3A2023-08-03..2023-09-06&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2023-08-03..2023-09-06&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2023-08-03..2023-09-06&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Akrassowski+updated%3A2023-08-03..2023-09-06&type=Issues)

## 4.0.2

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v4.0.1...929b801ab0e3df63d24f277630c2d3ab6d3be146))

### Enhancements made

- Clear input state if applicable before hopping out of normal mode to jupyter command mode [#82](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/82) ([@ryantam626](https://github.com/ryantam626))

### Bugs fixed

- fix: override browser shift-esc in command mode [#100](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/100) ([@ianhi](https://github.com/ianhi))
  - Additional thanks to [@petergthatsme](https://github.com/petergthatsme) [@firai](https://github.com/firai) [@lukashergt](https://github.com/lukashergt) for reporting, debugging and testing
- Fix `__init__.py` for wheel [#99](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/99) ([@fcollonval](https://github.com/fcollonval))

### Maintenance and upkeep improvements

- fix: dev install + lint issues [#97](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/97) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2023-08-01&to=2023-08-03&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Afcollonval+updated%3A2023-08-01..2023-08-03&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2023-08-01..2023-08-03&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2023-08-01..2023-08-03&type=Issues) | [@ryantam626](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aryantam626+updated%3A2023-08-01..2023-08-03&type=Issues)

## 4.0.1

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v4.0.0...9aa55aad927c578d91e51f351bb5bcf987d03c46))

### Enhancements made

- build: don't require package.json for python import [#93](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/93) ([@ianhi](https://github.com/ianhi))

### Bugs fixed

- Fix for attempting to update editor when there was none [#95](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/95) ([@krassowski](https://github.com/krassowski))

### Maintenance and upkeep improvements

- style: lint [#96](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/96) ([@ianhi](https://github.com/ianhi))
- build: don't require package.json for python import [#93](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/93) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2023-07-31&to=2023-08-01&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2023-07-31..2023-08-01&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2023-07-31..2023-08-01&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Akrassowski+updated%3A2023-07-31..2023-08-01&type=Issues)

## 4.0.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-vim/compare/v0.14.2...718d294cbbab1010ffaf35c79773e3abc5d98a6c))

### Enhancements made

- Add support for vim mode in Text Editor [#90](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/90) ([@krassowski](https://github.com/krassowski))

### Bugs fixed

- Fix undo [#92](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/92) ([@krassowski](https://github.com/krassowski))
- BUG: Arrow keys navigation causes double cell hops [#77](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/77) ([@alexveden](https://github.com/alexveden))

### Maintenance and upkeep improvements

- Remove duplicate binder-on-pr action [#91](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/91) ([@krassowski](https://github.com/krassowski))
- maintenance: Release updates [#87](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/87) ([@ianhi](https://github.com/ianhi))
- Support JupyterLab 4.0 [#85](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/85) ([@krassowski](https://github.com/krassowski))

### Other merged PRs

- Add configuration to provide custom keybindings [#74](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/74) ([@peytondmurray](https://github.com/peytondmurray))
- Add "leave-current-mode" command to move insert->normal->command. [#69](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/69) ([@asford](https://github.com/asford))
- restore correct keybinding [#64](https://github.com/jupyterlab-contrib/jupyterlab-vim/pull/64) ([@ianhi](https://github.com/ianhi))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-vim/graphs/contributors?from=2022-03-12&to=2023-07-31&type=c))

[@alexveden](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aalexveden+updated%3A2022-03-12..2023-07-31&type=Issues) | [@asford](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aasford+updated%3A2022-03-12..2023-07-31&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Agithub-actions+updated%3A2022-03-12..2023-07-31&type=Issues) | [@ianhi](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Aianhi+updated%3A2022-03-12..2023-07-31&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Akrassowski+updated%3A2022-03-12..2023-07-31&type=Issues) | [@peytondmurray](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-vim+involves%3Apeytondmurray+updated%3A2022-03-12..2023-07-31&type=Issues)

# History

## 0.17.0 / 2023-07-30

- Support JupyterLab 4.0 (#85, thanks @krassowski)

## 0.16.0 / 2023-03-12

- Add configuration to provide custom keybindings (#74, thanks @peytondmurray)
- Add bindable command to move insert-to-normal-to-command modes (#69, thanks @asford)
- Fix bug where arrow keys navigation caused double cell hops (#77, thanks @alexveden)

## 0.15.1 / 2022-03-12

- Fixed a bug in `0.15.0` where you could no longer type `c`.

## 0.15.0 / 2022-03-11

- Homogenize the project with the jupyterlab-contrib organization (#46)
- Fix `Esc` being override by the shortcuts extensions in jupyterlab
- Restructure Project Code and make keybindings user modifiable (#58)
- Add a menu button for enable/disable (#58)

## 0.14.0 / 2021-05-04

- Add ability to enable/disable plugin in settings (#24)

## 0.13.3 / 2021-02-22

- Fix saving column position when moving by lines (#28)

## 0.13.0 / 2020-12-10

- Support JupyterLab 3+
- Set up eslint and prettier

## 0.12.4 / 2020-05-20

- Switch from travis to GitHub actions.
- Auto deployment when merging to master.
- Auto bump of versions.

## 0.12.3 / 2020-04-25

- `z c` hides selected code cell
- `z o` shows selected code cell
- `z m` hides all code cells
- `z r` shows all code cells

## 0.12.2 / 2020-03-09

- Change package.json information

## 0.12.1 / 2020-03-06

- `ctrl [` exits Vim insert mode

## 0.12.0 / 2020-03-06

- Support JupyterLab 2.0.0+

## 0.11.0 / 2019-07-13

- Support JupyterLab 1.0.0+

## 0.10.1 / 2018-11-21

- `ctrl i` enters Vim insert mode from Jupyter command mode (#71) Thanks @wmayner

## 0.10.0 / 2018-10-08

- Update for JupyterLab 0.35

## 0.9.0 / 2018-08-22

- Update for JupyterLab 0.34 (#57) Thanks @MisterVulcan

## 0.8.0 / 2018-08-01

- Update for JupyterLab 0.33 (#52) Thanks @ah-

## 0.7.0 / 2018-04-16

- Requires JupyterLab 0.32 (Beta 2)
- ctrl-g shows function signature (#36)

## 0.6.0 / 2018-03-28

- center cell command (#33)
- `-` splits cell in vim command mode (#33)
- ctrl-c copies instead of leaving insert mode if you aren't on a mac (#34)

## 0.5.0 / 2018-03-27

- add moving cell commands
- Add delete/yank/paste cell commands (#28)
- select first and last cell shortcuts (#24)
- change to focus selector to fix debug prompt select

## 0.4.1 / 2018-02-14

- Ctrl-J and Ctrl-K execute markdown when leaving the cell.

## 0.4.0 / 2018-02-13

- Added Command/Ctrl-{1,2,3} to switch cell mode to code, markdown and raw.

## 0.3.0 / 2018-02-12

- Ex commands ':q' and ':quit' leave vim mode

## 0.2.1 / 2018-01-13

- bump package requirements, revert unnecessary commands for staying in edit mode
- ":w" saves notebook

## 0.2.0 / 2018-01-12

- Update to JupyterLab 0.31 (Beta1)

## 0.1.0 / 2017-12-09

- Initial Release!
- Vim mode in notebook cells
- Copy, Cut, Paste commands
- Vim motions moving between cells
- Several commands extended to remain in Vim mode
